package com.ruoyi.project.pssr.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.pssr.domain.TPssrPatrol;

/**
 * 巡检Mapper接口
 *
 * @author ssy
 * @date 2024-09-18
 */
public interface TPssrPatrolMapper
{
    /**
     * 查询巡检
     *
     * @param id 巡检ID
     * @return 巡检
     */
    public TPssrPatrol selectTPssrPatrolById(Long id);
    public int selectNoConfirmCount(Long subId);

    /**
     * 查询巡检列表
     *
     * @param tPssrPatrol 巡检
     * @return 巡检集合
     */
    public List<TPssrPatrol> selectTPssrPatrolList(TPssrPatrol tPssrPatrol);

    /**
     * 新增巡检
     *
     * @param tPssrPatrol 巡检
     * @return 结果
     */
    public int insertTPssrPatrol(TPssrPatrol tPssrPatrol);

    /**
     * 修改巡检
     *
     * @param tPssrPatrol 巡检
     * @return 结果
     */
    public int updateTPssrPatrol(TPssrPatrol tPssrPatrol);
    public int updateTPssrPatrolByIds(TPssrPatrol tPssrPatrol);


    /**
     * 删除巡检
     *
     * @param id 巡检ID
     * @return 结果
     */
    public int deleteTPssrPatrolById(Long id);

    /**
     * 批量删除巡检
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTPssrPatrolByIds(Long[] ids);
}
